\name{SeaIceModes}
\alias{SeaIceModes}
\title{
  Computes sea ice variability modes
}
\description{
  This function computes sea ice variability modes based on the K-means
  clustering method applied to sea ice area, extent, volume or thickness
  averages over the selected regions in the Arctic.
}
\usage{
  SeaIceModes(var, exp, obs, sdates, seasoninf, seasonsup, nclusters=NULL, nleadtime=NULL, nmember=NULL, leadtimemin=1, leadtimemax=NULL, storefreq="monthly", sampleperiod=1, pldgr=0, datagrid=N3.2_O1L42, listregs=NULL)
}
\arguments{
  \item{var}{
    sia, sie, siv, and sit (sea ice area, extent, volume and thickness).
    exp, obs, sdates, nleadtime, nmember, leadtimemin, leadtimemax, storefreq and
    sampleperiod are the same ass in Load: only var, exp, obs and sdates are mandatory, 
    and only 1 experiment or only 1 observational dataset can be loaded.
  }
  \item{seasoninf}{
    Month of the year when to start computing the extended seasonal means: 1 to 12.
  }
  \item{seasonsup}{
    Month of the year when to stop computing the extended seasonal means: 1 to 12. 
    The extended seasonal means can overlap the 31s December: e.g., DJF average.
    For monthly means put the same vales for sasoninf and seasonsup.
  }
  \item{nclusters}{
    K number of clusters to be computed, or K initial cluster centers (default is NULL
    and then Cluster.R  will determine the optimal number of clusters and their centers).
  }
  \item{pldgr}{
    pldgr<0 for using the full values, 0 for removing the long-term mean, and 0<pldgr for
    using residulas after removing polynomial fit of the pldgr order/degree (deafult is 0).
  }
  \item{datagrid}{
    Specify what NEMO or EC-Earth or obs dataset grid is being used 
    (default is N3.2_O1L42).
  }
  \item{listregs}{
    The list of sea ice regions/zones/points used must be specified.
  }
}
\value{
  \item{$clusters}{ 
    3-dimensional tensor (x, y, nclusters) containing the centroides of clusters.
  }
  \item{$pvalue}{
    3-dimensional tensor (x, y, nclusters) containing the pvalue of the centroide 
    anomalies obtained through t-test that accounts for the serial dependence of data.
  }
  \item{$occurrences}{
    1-dimension array (time) containing 1 or 2 or ... when a given cluster occurs. 
  }
}
\examples{


}
\author{
  History:
  1.0  #  2014-09  (N.S. Fuckar, neven.fuckar@ic3.cat)  #  Original code
}
\keyword{datagen}
